- mapping
Set of aesthetic mappings created by aes() or
aes_(). If specified and inherit.aes = TRUE (the
default), it is combined with the default mapping at the top level of the
plot. You must supply mapping if there is no plot mapping.
- data
to be displayed in this layer
- show.legend
logical. Should this layer be included in the legends?
NA, the default, includes if any aesthetics are mapped.
FALSE never includes, and TRUE always includes.
It can also be a named logical vector to finely select the aesthetics to
display.
- na.rm
If FALSE, the default, missing values are removed with
a warning. If TRUE, missing values are silently removed.
- inherit.aes
If FALSE, overrides the default aesthetics,
rather than combining with them.
- init_angle
Circle drawing starting angle.
- r
Circle radius, should be <= 0.5.
- color
Color of circles/fragments of circles borders.
- linewidth
Size of circles/fragments of circles borders.
- ...
other arguments passed on to layer().